/******************************************************************************/
/* TEKNISA                                                                    */
/******************************************************************************/
/*                                                                            */
/* NOME: GRAVA_LOGITEMAUTF                                                    */
/*                                                                            */
/* DESCRIO:                                                                 */
/*   Grava log de LOGITEMAUTF                                                 */
/*                                                                            */
/* CRIAO:                                                                   */
/* 18/02/2004 - Luiz Otvio de Souza                                          */
/*                                                                            */
/******************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'GRAVA_LOGITEMAUTF'  and
            type = 'TR'                 and
            u.uid = o.uid               and
            u.name = USER)
  DROP TRIGGER GRAVA_LOGITEMAUTF
  GO

CREATE TRIGGER GRAVA_LOGITEMAUTF
ON ITEMAUTF
FOR INSERT, UPDATE, DELETE

AS

DECLARE @V_IDGRAVLOGAF  VARCHAR(03);
DECLARE @V_DSRDMUSLITAF VARCHAR(50);
DECLARE @V_DSENDUSLITAF VARCHAR(50);
DECLARE @V_DSNMUSULITAF VARCHAR(50);
DECLARE @V_DSMETUSLITAF VARCHAR(250);
DECLARE @V_CDOPELOGITAF VARCHAR(12);

/* Variveis do cursor */
DECLARE @V_IDCOMANDO         VARCHAR(1);
DECLARE @V_CDFILDEST         VARCHAR(4);
DECLARE @V_CDFILLANC         VARCHAR(4);
DECLARE @V_NRAUTOFORN        VARCHAR(10);
DECLARE @V_CDMARCA           VARCHAR(5);
DECLARE @V_CDPRODUTO         VARCHAR(10);
DECLARE @V_DTPROGENTAF       DATETIME;
DECLARE @V_OLD_QTPROGENTAF   DOUBLE PRECISION;
DECLARE @V_NEW_QTPROGENTAF   DOUBLE PRECISION;
DECLARE @V_OLD_VRPREUNIAF    DOUBLE PRECISION;
DECLARE @V_NEW_VRPREUNIAF    DOUBLE PRECISION;
DECLARE @V_OLD_IDBAIXITMAF   VARCHAR(1);
DECLARE @V_NEW_IDBAIXITMAF   VARCHAR(1);
DECLARE @V_DTENTRITMSOL      DATETIME;
DECLARE @V_OLD_VRPERDESAF    DOUBLE PRECISION;
DECLARE @V_NEW_VRPERDESAF    DOUBLE PRECISION;
DECLARE @V_OLD_DTEFETENTAF   DATETIME;
DECLARE @V_NEW_DTEFETENTAF   DATETIME;
DECLARE @V_OLD_QTEFETENTRAF  DOUBLE PRECISION;
DECLARE @V_NEW_QTEFETENTRAF  DOUBLE PRECISION;
DECLARE @V_OLD_DSINCONSITAF  VARCHAR(2000);
DECLARE @V_NEW_DSINCONSITAF  VARCHAR(2000);


BEGIN
   DECLARE C_DADOS CURSOR FOR
     SELECT
       'D' IDCOMANDO,
       CDFILDEST,
       CDFILLANC,
       NRAUTOFORN,
       CDMARCA,
       CDPRODUTO,
       DTPROGENTAF,
       QTPROGENTAF,
       QTPROGENTAF,
       VRPREUNIAF,
       VRPREUNIAF,
       IDBAIXITMAF,
       IDBAIXITMAF,
       DTEFETENTAF,
       VRPERDESAF,
       VRPERDESAF,
       DTEFETENTAF,
       DTEFETENTAF,
       QTEFETENTRAF,
       QTEFETENTRAF
       /* DSINCONSITAF  Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */
       /* DSINCONSITAF  Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */
     FROM
       DELETED
     WHERE
       0 = (SELECT COUNT(*) FROM INSERTED)

     UNION ALL

     SELECT
       'U' IDCOMANDO,
       INSERTED.CDFILDEST,
       INSERTED.CDFILLANC,
       INSERTED.NRAUTOFORN,
       INSERTED.CDMARCA,
       INSERTED.CDPRODUTO,
       INSERTED.DTPROGENTAF,
       DELETED.QTPROGENTAF,
       INSERTED.QTPROGENTAF,
       DELETED.VRPREUNIAF,
       INSERTED.VRPREUNIAF,
       DELETED.IDBAIXITMAF,
       INSERTED.IDBAIXITMAF,
       INSERTED.DTEFETENTAF,
       DELETED.VRPERDESAF,
       INSERTED.VRPERDESAF,
       DELETED.DTEFETENTAF,
       INSERTED.DTEFETENTAF,
       DELETED.QTEFETENTRAF,
       INSERTED.QTEFETENTRAF
       /* DELETED.DSINCONSITAF   Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */
       /* INSERTED.DSINCONSITAF  Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */

     FROM
       INSERTED,
       DELETED
     WHERE
       INSERTED.CDFILDEST   = DELETED.CDFILDEST    AND
       INSERTED.CDFILLANC   = DELETED.CDFILLANC    AND
       INSERTED.NRAUTOFORN  = DELETED.NRAUTOFORN   AND
       INSERTED.DTPROGENTAF = DELETED.DTPROGENTAF  AND
       INSERTED.CDPRODUTO   = DELETED.CDPRODUTO    AND
       INSERTED.CDMARCA     = DELETED.CDMARCA

     UNION ALL

     SELECT
       'I' IDCOMANDO,
       CDFILDEST,
       CDFILLANC,
       NRAUTOFORN,
       CDMARCA,
       CDPRODUTO,
       DTPROGENTAF,
       QTPROGENTAF,
       QTPROGENTAF,
       VRPREUNIAF,
       VRPREUNIAF,
       IDBAIXITMAF,
       IDBAIXITMAF,
       DTEFETENTAF,
       VRPERDESAF,
       VRPERDESAF,
       DTEFETENTAF,
       DTEFETENTAF,
       QTEFETENTRAF,
       QTEFETENTRAF
       /* DSINCONSITAF  Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */
       /* DSINCONSITAF Cannot use text, ntext, or image columns in the 'inserted' and 'deleted' tables. */
     FROM
       INSERTED
     WHERE
       0 = (SELECT COUNT(*) FROM DELETED)


   OPEN C_DADOS;
   FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                @V_CDFILDEST,       
                                @V_CDFILLANC,
                                @V_NRAUTOFORN,
                                @V_CDMARCA,
                                @V_CDPRODUTO,
                                @V_DTPROGENTAF,
                                @V_OLD_QTPROGENTAF,
                                @V_NEW_QTPROGENTAF,
                                @V_OLD_VRPREUNIAF,
                                @V_NEW_VRPREUNIAF,
                                @V_OLD_IDBAIXITMAF,
                                @V_NEW_IDBAIXITMAF,
                                @V_DTENTRITMSOL,
                                @V_OLD_VRPERDESAF,
                                @V_NEW_VRPERDESAF,
                                @V_OLD_DTEFETENTAF,
                                @V_NEW_DTEFETENTAF,
                                @V_OLD_QTEFETENTRAF,
                                @V_NEW_QTEFETENTRAF;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_IDGRAVLOGAF = 'SSS';
      SELECT @V_IDGRAVLOGAF = ISNULL(MAX(IDGRAVLOGAF), 'SSS')
      FROM PARASUPRI
      WHERE (CDFILIAL = (SELECT ISNULL(CDFILCENTCMP, CDFILIAL)
                         FROM FILIAL
                         WHERE (CDFILIAL = @V_CDFILDEST)));

      /*SET @V_DSRDMUSLITAF = 'VIA BD';
      SET @V_DSENDUSLITAF = 'VIA BD';
      SET @V_DSNMUSULITAF = 'VIA BD';
      SET @V_DSMETUSLITAF = 'VIA BD';
      SET @V_CDOPELOGITAF = 'VIA BD';
      SELECT @V_DSRDMUSLITAF = ISNULL(MAX(DSSERVERRDM),  'VIA BD'),
             @V_DSENDUSLITAF = ISNULL(MAX(DSREMOTEADDR), 'VIA BD'),
             @V_DSNMUSULITAF = ISNULL(MAX(DSREMOTEHOST), 'VIA BD'),
             @V_DSMETUSLITAF = ISNULL(MAX(DSSERVMETHOD), 'VIA BD'),
             @V_CDOPELOGITAF = ISNULL(MAX(DSREMOTEOPER), 'VIA BD')
      FROM SQLWEBTUNNING
      WHERE NRAUDSID = @@SPID AND
            CONVERT(DATETIME, CONVERT(VARCHAR, DTSTARTDATE, 103))  =
                         (SELECT MAX(DTSTARTDATE)
                                  FROM SQLWEBTUNNING S
                                  WHERE S.NRAUDSID = @@SPID);*/
      EXEC WEBTUNNING @P_DSREMOTEADDR = @V_DSENDUSLITAF OUTPUT,
                      @P_DSREMOTEHOST = @V_DSNMUSULITAF OUTPUT,
                      @P_DSSERVERRDM  = @V_DSRDMUSLITAF OUTPUT,
                      @P_DSSERVMETHOD = @V_DSMETUSLITAF OUTPUT,
                      @P_DSREMOTEOPER = @V_CDOPELOGITAF OUTPUT;

      IF @V_IDCOMANDO = 'I' BEGIN

         IF SUBSTRING(@V_IDGRAVLOGAF, 1, 1) = 'S' BEGIN

            INSERT INTO LOGITEMAUTF
            (CDFIDESLITAF, CDFILANLITAF, NRAUTOFLITAF, CDMARCALITAF, CDPRODLITAF,  DTPROGLITAF,
             QTPROGENTANT, QTPROGENTDEP, VRPREUNIANT,  VRPREUNIDEP,  IDBAIXITANT,  IDBAIXITDEP,
             DSINCITAFANT, DSINCITAFDEP, DTEITSOLITAF, VRPERDEAFANT, VRPERDEAFDEP, DTEFETEAFANT,
             DTEFETEAFDEP, QTEFETEAFANT, QTEFETEAFDEP, IDOPERALITAF, DSRDMUSLITAF, DSENDUSLITAF,
             DSNMUSULITAF, DSMETUSLITAF, CDOPELOGITAF, DTOPERAITAF)
            VALUES
            (@V_CDFILDEST, @V_CDFILLANC, @V_NRAUTOFORN, @V_CDMARCA, @V_CDPRODUTO, @V_DTPROGENTAF,
             0, @V_NEW_QTPROGENTAF, 0, @V_NEW_VRPREUNIAF, NULL, @V_NEW_IDBAIXITMAF,
             NULL, @V_NEW_DSINCONSITAF, @V_DTENTRITMSOL, 0, @V_NEW_VRPERDESAF, NULL,
             @V_NEW_DTEFETENTAF, 0, @V_NEW_QTEFETENTRAF, 'I', @V_DSRDMUSLITAF, @V_DSENDUSLITAF,
             @V_DSNMUSULITAF, @V_DSMETUSLITAF, @V_CDOPELOGITAF, GETDATE());

         END;

      END;

      IF @V_IDCOMANDO = 'U' BEGIN

         IF SUBSTRING(@V_IDGRAVLOGAF, 2, 1) = 'S' BEGIN

            INSERT INTO LOGITEMAUTF
            (CDFIDESLITAF, CDFILANLITAF, NRAUTOFLITAF, CDMARCALITAF, CDPRODLITAF,  DTPROGLITAF,
             QTPROGENTANT, QTPROGENTDEP, VRPREUNIANT,  VRPREUNIDEP,  IDBAIXITANT,  IDBAIXITDEP,
             DSINCITAFANT, DSINCITAFDEP, DTEITSOLITAF, VRPERDEAFANT, VRPERDEAFDEP, DTEFETEAFANT,
             DTEFETEAFDEP, QTEFETEAFANT, QTEFETEAFDEP, IDOPERALITAF, DSRDMUSLITAF, DSENDUSLITAF,
             DSNMUSULITAF, DSMETUSLITAF, CDOPELOGITAF, DTOPERAITAF)
            VALUES
            (@V_CDFILDEST, @V_CDFILLANC, @V_NRAUTOFORN, @V_CDMARCA, @V_CDPRODUTO, @V_DTPROGENTAF,
             @V_OLD_QTPROGENTAF, @V_NEW_QTPROGENTAF, @V_OLD_VRPREUNIAF, @V_NEW_VRPREUNIAF, @V_OLD_IDBAIXITMAF, @V_NEW_IDBAIXITMAF,
             @V_OLD_DSINCONSITAF, @V_NEW_DSINCONSITAF, @V_DTENTRITMSOL, @V_OLD_VRPERDESAF, @V_NEW_VRPERDESAF, @V_OLD_DTEFETENTAF,
             @V_NEW_DTEFETENTAF, @V_OLD_QTEFETENTRAF, @V_NEW_QTEFETENTRAF, 'A', @V_DSRDMUSLITAF, @V_DSENDUSLITAF,
             @V_DSNMUSULITAF, @V_DSMETUSLITAF, @V_CDOPELOGITAF, GETDATE());

         END;

      END;

      IF @V_IDCOMANDO = 'D' /* DELETING */ BEGIN

         IF SUBSTRING(@V_IDGRAVLOGAF, 3, 1) = 'S' BEGIN

            INSERT INTO LOGITEMAUTF
            (CDFIDESLITAF, CDFILANLITAF, NRAUTOFLITAF, CDMARCALITAF, CDPRODLITAF,  DTPROGLITAF,
             QTPROGENTANT, QTPROGENTDEP, VRPREUNIANT,  VRPREUNIDEP,  IDBAIXITANT,  IDBAIXITDEP,
             DSINCITAFANT, DSINCITAFDEP, DTEITSOLITAF, VRPERDEAFANT, VRPERDEAFDEP, DTEFETEAFANT,
             DTEFETEAFDEP, QTEFETEAFANT, QTEFETEAFDEP, IDOPERALITAF, DSRDMUSLITAF, DSENDUSLITAF,
             DSNMUSULITAF, DSMETUSLITAF, CDOPELOGITAF, DTOPERAITAF)
            VALUES
            (@V_CDFILDEST, @V_CDFILLANC, @V_NRAUTOFORN, @V_CDMARCA, @V_CDPRODUTO, @V_DTPROGENTAF,
             @V_OLD_QTPROGENTAF, @V_OLD_QTPROGENTAF, @V_OLD_VRPREUNIAF, @V_OLD_VRPREUNIAF, @V_OLD_IDBAIXITMAF, @V_OLD_IDBAIXITMAF,
             @V_OLD_DSINCONSITAF, @V_OLD_DSINCONSITAF, @V_DTENTRITMSOL, @V_OLD_VRPERDESAF, @V_OLD_VRPERDESAF, @V_OLD_DTEFETENTAF,
             @V_OLD_DTEFETENTAF, @V_OLD_QTEFETENTRAF, @V_OLD_QTEFETENTRAF, 'E', @V_DSRDMUSLITAF, @V_DSENDUSLITAF,
             @V_DSNMUSULITAF, @V_DSMETUSLITAF, @V_CDOPELOGITAF, GETDATE());

         END;

      END;
      FETCH NEXT FROM C_DADOS INTO @V_IDCOMANDO,
                                   @V_CDFILDEST,
                                   @V_CDFILLANC,
                                   @V_NRAUTOFORN,
                                   @V_CDMARCA,
                                   @V_CDPRODUTO,
                                   @V_DTPROGENTAF,
                                   @V_OLD_QTPROGENTAF,
                                   @V_NEW_QTPROGENTAF,
                                   @V_OLD_VRPREUNIAF,
                                   @V_NEW_VRPREUNIAF,
                                   @V_OLD_IDBAIXITMAF,
                                   @V_NEW_IDBAIXITMAF,
                                   @V_DTENTRITMSOL,
                                   @V_OLD_VRPERDESAF,
                                   @V_NEW_VRPERDESAF,
                                   @V_OLD_DTEFETENTAF,
                                   @V_NEW_DTEFETENTAF,
                                   @V_OLD_QTEFETENTRAF,
                                   @V_NEW_QTEFETENTRAF;
   END;
   CLOSE C_DADOS;
   DEALLOCATE C_DADOS;
END;
GO
